/**
 * Copyright 2005 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.nutch.indexer.extra;

import java.io.IOException;
import java.io.InputStream;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.nutch.util.NutchConfiguration;
import org.jdom.Document;
import org.jdom.Element;
import org.jdom.JDOMException;
import org.jdom.input.SAXBuilder;
import org.jdom.xpath.XPath;

public class ExtraIndexingFilterConfig {

	public static final Log LOG = LogFactory.getLog("org.apache.nutch.indexer.extra");

	private static ExtraIndexingFilterConfig extraIndexingFilterConfig = null;

	private List extraIndexingMetaData;

	private ExtraIndexingFilterConfig() {
	}

	public static ExtraIndexingFilterConfig getInstance()
	{
		if (extraIndexingFilterConfig == null)
		{
			InputStream configInputStream =
				NutchConfiguration.create().getConfResourceAsInputStream("index-extra-conf.xml");
			LOG.info("extraIndexingFilter config path : "
				+ NutchConfiguration.create().get("index-extra-conf.xml"));
			extraIndexingFilterConfig = new ExtraIndexingFilterConfig();
			Document doc = parseXml(configInputStream);
			extraIndexingFilterConfig = populateConfig(doc);			
		}
		return extraIndexingFilterConfig;
	}

	public static Document parseXml(InputStream is) {
		org.jdom.Document xmlDoc = new org.jdom.Document();
		try {
			SAXBuilder builder = new SAXBuilder();
			builder.setValidation(false);
			xmlDoc = builder.build(is);
		} catch (JDOMException e) {
			LOG.error("extraIndexingFilter JDOMException: " + e.toString());
		} catch (IOException e) {
			LOG.error("extraIndexingFilter IOException: " + e.toString());
		}
		return xmlDoc;
	}

	private static ExtraIndexingFilterConfig populateConfig(Document doc)
	{
		List listOut = new ArrayList();
		try
		{
			List list = XPath.selectNodes(doc, "//ExtraIndexingMetaData");
			Iterator i = list.iterator();
			while (i.hasNext())
			{
				ExtraIndexingMetaData extraIndexingMetaData = new ExtraIndexingMetaData();
				Element element = (Element) i.next();
				extraIndexingMetaData.setMetaData(element);
				listOut.add(extraIndexingMetaData);
			}
		}
		catch (JDOMException e)
		{

		}
		extraIndexingFilterConfig.setExtraIndexerProperties(listOut);
		return extraIndexingFilterConfig;
	}

	public List getExtraIndexerProperties()
	{
		return extraIndexingMetaData;
	}

	public void setExtraIndexerProperties(List extraIndexingMetaData)
	{
		this.extraIndexingMetaData = extraIndexingMetaData;
	}	
}