/**
 * Copyright 2006 The Apache Software Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.nutch.indexer.extra;

import org.jdom.Element;

/**
 * This class encapsulates a set of fields parsed from the index-extra-conf.xml
 * configuration file.
 *  
 * @author Alan Tanaman (alan.tanaman NOSPAM-AT-NOSPAM idna-solutions.com)
 */
public class ExtraIndexingMetaData {

	public enum SourceType
	{
		FIELD("FIELD"),
		JAVA("JAVA"),
		TEXT("TEXT"),
		META("META"),
		CONST("CONST");
		public final String text;
		private SourceType (String i_text)
		{
			text = i_text;
		}
	}

	private String name;
	private String stored;
	private String indexed;
	private String termVector = "NO";
	private String boost = "1.0";
	private String condition = null;
	private SourceType sourceType;
	private String sourceValue;
	private String regexValue = null;
	private int regexNo = 1;
	
	public String getName() {
		return name;
	}

	public String getStored() {
		return stored;
	}

	public String getIndexed() {
		return indexed;
	}

	public String getTermVector() {
		return termVector;
	}

	public String getBoost() {
		return boost;
	}

	public String getCondition() {
		return condition;
	}
	
	public SourceType getSourceType() {
		return sourceType;
	}

	public String getSourceValue() {
		return sourceValue;
	}

	public String getRegexValue() {
		return regexValue;
	}

	public int getRegexNo() {
		return regexNo;
	}

	public void setMetaData(Element element) {
		this.name = element.getAttributeValue("name");

		this.stored = element.getAttributeValue("stored").toUpperCase();
		this.indexed = element.getAttributeValue("indexed").toUpperCase();
		if (element.getAttribute("termVector") != null)
			this.termVector = element.getAttributeValue("termVector").toUpperCase();

		if (element.getAttribute("boost") != null)
			this.boost = element.getAttributeValue("boost");

		if (element.getAttribute("condition") != null)
			this.condition = element.getAttributeValue("condition");

		this.sourceType = SourceType.valueOf(element.getAttributeValue("sourceType").toUpperCase());			
		if (element.getAttribute("sourceValue") != null)
			this.sourceValue = element.getAttributeValue("sourceValue");
		
		if (element.getAttribute("regexValue") != null)
		{
			this.regexValue = element.getAttributeValue("regexValue");
			if (element.getAttribute("regexNo") != null)
				this.regexNo = Integer.parseInt(element.getAttributeValue("regexNo"));
		}
		
	}
}
